==> renderkit-7.x-1.6.tar.gz: renderkit/src/EntityDisplay/EntityDisplay_ListOfRelatedEntities.php <==
<?php

namespace Drupal\renderkit\EntityDisplay;

use Drupal\renderkit\EntitiesListFormat\EntitiesListFormatInterface;
use Drupal\renderkit\EntityToEntities\EntityToEntitiesInterface;
use Drupal\renderkit\Util\EntityUtil;

/**
 * @CfrPlugin("listOfRelatedEntities", "Related entities")
 */
class EntityDisplay_ListOfRelatedEntities extends EntitiesDisplayBase {

  /**
   * @var \Drupal\renderkit\EntityToEntities\EntityToEntitiesInterface
   */
  private $entityToEntities;

  /**
   * @var \Drupal\renderkit\EntitiesListFormat\EntitiesListFormatInterface
   */
  private $entitiesListFormat;

  /**
   * @param \Drupal\renderkit\EntityToEntities\EntityToEntitiesInterface $entityToEntities
   * @param \Drupal\renderkit\EntitiesListFormat\EntitiesListFormatInterface $entitiesListFormat
   */
  public function __construct(EntityToEntitiesInterface $entityToEntities, EntitiesListFormatInterface $entitiesListFormat) {
    $this->entityToEntities = $entityToEntities;
    $this->entitiesListFormat = $entitiesListFormat;
  }

  /**
   * Builds render arrays from the entities provided.
   *
   * Both the entities and the resulting render arrays are in plural, to allow
   * for more performant implementations.
   *
   * Array keys and their order must be preserved, although implementations
   * might remove some keys that are empty.
   *
   * @param string $entityType
   *   E.g. 'node' or 'taxonomy_term'.
   * @param object[] $entities
   *   Entity objects for which to build the render arrays.
   *   The array keys can be anything, they don't need to be the entity ids.
   *
   * @return array[]
   *   An array of render arrays, keyed by the original array keys of $entities.
   */
  public function buildEntities($entityType, array $entities) {

    /**
     * @var object[][] $targetEntitiess
     *   Format: $[$sourceEntityDelta][$targetEntityDelta] = $targetEntity
     */
    $targetEntitiess = $this->entityToEntities->entitiesGetRelated($entityType, $entities);

    $targetEntitiess = EntityUtil::entitiessCheckAccess(
      $targetEntityType = $this->entityToEntities->getTargetEntityType(),
      $targetEntitiess);

    $builds = [];
    foreach ($targetEntitiess as $sourceEntityDelta => $targetEntities) {

      $builds[$sourceEntityDelta] = $this->entitiesListFormat->entitiesBuildList(
        $targetEntityType,
        $targetEntities);
    }

    return $builds;
  }
}

==> renderkit-7.x-1.7.tar.gz: renderkit/src/EntityDisplay/EntityDisplay_ListOfRelatedEntities.php <==
<?php

namespace Drupal\renderkit\EntityDisplay;

use Drupal\cfrapi\Context\CfrContextInterface;
use Drupal\cfrreflection\Configurator\Configurator_CallbackConfigurable;
use Drupal\renderkit\EntitiesListFormat\EntitiesListFormatInterface;
use Drupal\renderkit\EntityToEntities\EntityToEntitiesInterface;
use Drupal\renderkit\Util\EntityUtil;

class EntityDisplay_ListOfRelatedEntities implements EntityDisplayInterface {

  /**
   * @var \Drupal\renderkit\EntityToEntities\EntityToEntitiesInterface
   */
  private $entityToEntities;

  /**
   * @var \Drupal\renderkit\EntitiesListFormat\EntitiesListFormatInterface
   */
  private $entitiesListFormat;

  /**
   * @CfrPlugin("listOfRelatedEntities", "Related entities")
   *
   * @param \Drupal\cfrapi\Context\CfrContextInterface $context
   *
   * @return \Drupal\cfrapi\Configurator\ConfiguratorInterface
   */
  public static function createConfigurator(CfrContextInterface $context = NULL) {
    return Configurator_CallbackConfigurable::createFromClassName(
      __CLASS__,
      [
        cfrplugin()->interfaceGetConfigurator(
          EntityToEntitiesInterface::class,
          $context),
        // This one is without context, because we don't know the target entity type.
        EntityDisplay::configurator(),
      ],
      [
        t('Entity to entities'),
        t('Entities list format for target entities'),
      ]
    );
  }



  /**
   * @param \Drupal\renderkit\EntityToEntities\EntityToEntitiesInterface $entityToEntities
   * @param \Drupal\renderkit\EntitiesListFormat\EntitiesListFormatInterface $entitiesListFormat
   */
  public function __construct(EntityToEntitiesInterface $entityToEntities, EntitiesListFormatInterface $entitiesListFormat) {
    $this->entityToEntities = $entityToEntities;
    $this->entitiesListFormat = $entitiesListFormat;
  }

  /**
   * Builds render arrays from the entities provided.
   *
   * Both the entities and the resulting render arrays are in plural, to allow
   * for more performant implementations.
   *
   * Array keys and their order must be preserved, although implementations
   * might remove some keys that are empty.
   *
   * @param string $entityType
   *   E.g. 'node' or 'taxonomy_term'.
   * @param object[] $entities
   *   Entity objects for which to build the render arrays.
   *   The array keys can be anything, they don't need to be the entity ids.
   *
   * @return array[]
   *   An array of render arrays, keyed by the original array keys of $entities.
   */
  public function buildEntities($entityType, array $entities) {

    /**
     * @var object[][] $targetEntitiess
     *   Format: $[$sourceEntityDelta][$targetEntityDelta] = $targetEntity
     */
    $targetEntitiess = $this->entityToEntities->entitiesGetRelated($entityType, $entities);

    $targetEntitiess = EntityUtil::entitiessCheckAccess(
      $targetEntityType = $this->entityToEntities->getTargetEntityType(),
      $targetEntitiess);

    $builds = [];
    foreach ($targetEntitiess as $sourceEntityDelta => $targetEntities) {

      $builds[$sourceEntityDelta] = $this->entitiesListFormat->entitiesBuildList(
        $targetEntityType,
        $targetEntities);
    }

    return $builds;
  }

  /**
   * Same as ->buildEntities(), just for a single entity.
   *
   * @param string $entity_type
   *   E.g. 'node' or 'taxonomy_term'.
   * @param object $entity
   *   Single entity object for which to build a render arary.
   *
   * @return array
   *   Render element that shows a list of target entities.
   */
  public function buildEntity($entity_type, $entity) {

    $targetEntities = $this->entityToEntities->entityGetRelated($entity_type, $entity);

    if ([] === $targetEntities) {
      return [];
    }

    $targetEntities = EntityUtil::entitiesCheckAccess(
      $targetEntityType = $this->entityToEntities->getTargetEntityType(),
      $targetEntities);

    if ([] === $targetEntities) {
      return [];
    }

    return $this->entitiesListFormat->entitiesBuildList(
      $targetEntityType,
      $targetEntities);
  }
}
